"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable @typescript-eslint/camelcase */
const fs = require("fs");
const os = require("os");
const path = require("path");
function setDatabasePaths(sqlitePath) {
    const correlationRepositoryConfig = readConfigFile('sqlite', 'correlation_repository.json');
    const externalTaskRepositoryConfig = readConfigFile('sqlite', 'external_task_repository.json');
    const flowNodeInstanceRepositoryConfig = readConfigFile('sqlite', 'flow_node_instance_repository.json');
    const processModelRepositoryConfig = readConfigFile('sqlite', 'process_model_repository.json');
    const databaseBasePath = getSqliteStoragePath(sqlitePath);
    const correlationRepositoryStoragePath = path.join(databaseBasePath, correlationRepositoryConfig.storage);
    const externalTaskRepositoryStoragePath = path.join(databaseBasePath, externalTaskRepositoryConfig.storage);
    const flowNodeRepositoryStoragePath = path.join(databaseBasePath, flowNodeInstanceRepositoryConfig.storage);
    const processModelRepositoryStoragePath = path.join(databaseBasePath, processModelRepositoryConfig.storage);
    const logsStoragePath = path.join(databaseBasePath, 'logs');
    process.env.process_engine__correlation_repository__storage = correlationRepositoryStoragePath;
    process.env.process_engine__external_task_repository__storage = externalTaskRepositoryStoragePath;
    process.env.process_engine__process_model_repository__storage = processModelRepositoryStoragePath;
    process.env.process_engine__flow_node_instance_repository__storage = flowNodeRepositoryStoragePath;
    process.env.process_engine__logging_repository__log_output_path = logsStoragePath;
}
exports.setDatabasePaths = setDatabasePaths;
function getSqliteStoragePath(sqlitePath) {
    if (sqlitePath) {
        return sqlitePath;
    }
    const userDataFolderPath = getUserConfigFolder();
    const userDataProcessEngineFolderName = 'process_engine_runtime';
    const processEngineDatabaseFolderName = 'databases';
    const databaseBasePath = path.resolve(userDataFolderPath, userDataProcessEngineFolderName, processEngineDatabaseFolderName);
    return databaseBasePath;
}
exports.getSqliteStoragePath = getSqliteStoragePath;
function getUserConfigFolder() {
    const userHomeDir = os.homedir();
    switch (process.platform) {
        case 'darwin':
            return path.join(userHomeDir, 'Library', 'Application Support');
        case 'win32':
            return path.join(userHomeDir, 'AppData', 'Roaming');
        default:
            return path.join(userHomeDir, '.config');
    }
}
exports.getUserConfigFolder = getUserConfigFolder;
function readConfigFile(env, repositoryConfigFileName) {
    const configFilePath = path.resolve(process.env.CONFIG_PATH, env, 'process_engine', repositoryConfigFileName);
    const fileContent = fs.readFileSync(configFilePath, 'utf-8');
    const parsedFileContent = JSON.parse(fileContent);
    return parsedFileContent;
}
exports.readConfigFile = readConfigFile;
//# sourceMappingURL=environment.js.map